@@ -1,8 +1,8 @@
 /*****************************************************************************
  * drms.h : DRMS
  *****************************************************************************
- * Copyright (C) 2004 VideoLAN
- * $Id: drms.h 10101 2005-03-02 16:47:31Z robux4 $
+ * Copyright (C) 2004 the VideoLAN team
+ * $Id$
  *
  * Author: Jon Lech Johansen <jon-vl@nanocrew.net>
  *
@@ -18,13 +18,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-extern void *drms_alloc( char *psz_homedir );
+#ifndef _VLC_DRMS_H
+#define _VLC_DRMS_H 1
+
+extern void *drms_alloc( const char *psz_homedir );
 extern void drms_free( void *p_drms );
 extern int drms_init( void *p_drms, uint32_t i_type,
                       uint8_t *p_info, uint32_t i_len );
 extern void drms_decrypt( void *p_drms, uint32_t *p_buffer,
                           uint32_t i_len );
 
+#endif
