@@ -1,8 +1,8 @@
 /*****************************************************************************
  * ps.c: Program Stream demux module for VLC.
  *****************************************************************************
- * Copyright (C) 2004 VideoLAN
- * $Id: ps.c 10234 2005-03-09 12:39:36Z gbazin $
+ * Copyright (C) 2004 the VideoLAN team
+ * $Id: 837a8ce31c3efa8ed7b8b006e180968b5df07969 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -18,16 +18,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include <stdlib.h>                                      /* malloc(), free() */
 
-#include <vlc/vlc.h>
-#include <vlc/input.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc_common.h>
+#include <vlc_plugin.h>
+#include <vlc_demux.h>
 
 #include "ps.h"
 
@@ -36,25 +40,33 @@
  *  - ...
  */
 
+#define TIME_TEXT N_("Trust MPEG timestamps")
+#define TIME_LONGTEXT N_("Normally we use the timestamps of the MPEG files " \
+    "to calculate position and duration. However sometimes this might not " \
+    "be usable. Disable this option to calculate from the bitrate instead." )
+
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
+static int  OpenForce( vlc_object_t * );
 static int  Open   ( vlc_object_t * );
-static int  OpenAlt( vlc_object_t * );
 static void Close  ( vlc_object_t * );
 
 vlc_module_begin();
-    set_description( _("PS demuxer") );
+    set_description( N_("MPEG-PS demuxer") );
     set_category( CAT_INPUT );
     set_subcategory( SUBCAT_INPUT_DEMUX );
-    set_capability( "demux2", 1 );
-    set_callbacks( Open, Close );
+    set_capability( "demux", 1 );
+    set_callbacks( OpenForce, Close );
     add_shortcut( "ps" );
 
+    add_bool( "ps-trust-timestamps", true, NULL, TIME_TEXT,
+                 TIME_LONGTEXT, true );
+
     add_submodule();
-    set_description( _("PS demuxer") );
-    set_capability( "demux2", 9 );
-    set_callbacks( OpenAlt, Close );
+    set_description( N_("MPEG-PS demuxer") );
+    set_capability( "demux", 8 );
+    set_callbacks( Open, Close );
 vlc_module_end();
 
 /*****************************************************************************
@@ -68,6 +80,13 @@ struct demux_sys_t
 
     int64_t     i_scr;
     int         i_mux_rate;
+    int64_t     i_length;
+    int         i_time_track;
+    int64_t     i_current_pts;
+
+    bool  b_lost_sync;
+    bool  b_have_pack;
+    bool  b_seekable;
 };
 
 static int Demux  ( demux_t *p_demux );
@@ -79,12 +98,12 @@ static block_t *ps_pkt_read   ( stream_t *, uint32_t i_code );
 /*****************************************************************************
  * Open
  *****************************************************************************/
-static int Open( vlc_object_t *p_this )
+static int OpenCommon( vlc_object_t *p_this, bool b_force )
 {
     demux_t     *p_demux = (demux_t*)p_this;
     demux_sys_t *p_sys;
 
-    uint8_t     *p_peek;
+    const uint8_t *p_peek;
 
     if( stream_Peek( p_demux->s, &p_peek, 4 ) < 4 )
     {
@@ -92,9 +111,11 @@ static int Open( vlc_object_t *p_this )
         return VLC_EGENERIC;
     }
 
-    if( p_peek[0] != 0 || p_peek[1] != 0 ||
-        p_peek[2] != 1 || p_peek[3] < 0xb9 )
+    if( memcmp( p_peek, "\x00\x00\x01", 3 ) || ( p_peek[3] < 0xb9 ) )
     {
+        if( !b_force )
+            return VLC_EGENERIC;
+
         msg_Warn( p_demux, "this does not look like an MPEG PS stream, "
                   "continuing anyway" );
     }
@@ -103,10 +124,20 @@ static int Open( vlc_object_t *p_this )
     p_demux->pf_demux = Demux;
     p_demux->pf_control = Control;
     p_demux->p_sys = p_sys = malloc( sizeof( demux_sys_t ) );
+    if( !p_sys ) return VLC_ENOMEM;
 
     /* Init p_sys */
     p_sys->i_mux_rate = 0;
     p_sys->i_scr      = -1;
+    p_sys->i_length   = -1;
+    p_sys->i_current_pts = (mtime_t) 0;
+    p_sys->i_time_track = -1;
+
+    p_sys->b_lost_sync = false;
+    p_sys->b_have_pack = false;
+    p_sys->b_seekable  = false;
+
+    stream_Control( p_demux->s, STREAM_CAN_SEEK, &p_sys->b_seekable );
 
     ps_psm_init( &p_sys->psm );
     ps_track_init( p_sys->tk );
@@ -116,24 +147,14 @@ static int Open( vlc_object_t *p_this )
     return VLC_SUCCESS;
 }
 
-static int OpenAlt( vlc_object_t *p_this )
+static int OpenForce( vlc_object_t *p_this )
 {
-    demux_t *p_demux = (demux_t*)p_this;
-    uint8_t *p_peek;
+    return OpenCommon( p_this, true );
+}
 
-    if( stream_Peek( p_demux->s, &p_peek, 4 ) < 4 )
-    {
-        msg_Err( p_demux, "cannot peek" );
-        return VLC_EGENERIC;
-    }
-
-    if( p_peek[0] != 0 || p_peek[1] != 0 ||
-        p_peek[2] != 1 || p_peek[3] < 0xb9 )
-    {
-        if( !p_demux->b_force ) return VLC_EGENERIC;
-    }
-
-    return Open( p_this );
+static int Open( vlc_object_t *p_this )
+{
+    return OpenCommon( p_this, ((demux_t *)p_this)->b_force );
 }
 
 /*****************************************************************************
@@ -160,6 +181,97 @@ static void Close( vlc_object_t *p_this )
     free( p_sys );
 }
 
+static int Demux2( demux_t *p_demux, bool b_end )
+{
+    demux_sys_t *p_sys = p_demux->p_sys;
+    int i_ret, i_id;
+    uint32_t i_code;
+    block_t *p_pkt;
+
+    i_ret = ps_pkt_resynch( p_demux->s, &i_code );
+    if( i_ret < 0 )
+    {
+        return 0;
+    }
+    else if( i_ret == 0 )
+    {
+        if( !p_sys->b_lost_sync )
+            msg_Warn( p_demux, "garbage at input, trying to resync..." );
+
+        p_sys->b_lost_sync = true;
+        return 1;
+    }
+
+    if( p_sys->b_lost_sync ) msg_Warn( p_demux, "found sync code" );
+    p_sys->b_lost_sync = false;
+
+    if( ( p_pkt = ps_pkt_read( p_demux->s, i_code ) ) == NULL )
+    {
+        return 0;
+    }
+    if( (i_id = ps_pkt_id( p_pkt )) >= 0xc0 )
+    {
+        ps_track_t *tk = &p_sys->tk[PS_ID_TO_TK(i_id)];
+        if( !ps_pkt_parse_pes( p_pkt, tk->i_skip ) )
+        {
+            if( b_end && p_pkt->i_pts > tk->i_last_pts )
+            {
+                tk->i_last_pts = p_pkt->i_pts;
+            }
+            else if ( tk->i_first_pts == -1 )
+            {
+                tk->i_first_pts = p_pkt->i_pts;
+            }
+        }
+    }
+    block_Release( p_pkt );
+    return 1;
+}
+
+static void FindLength( demux_t *p_demux )
+{
+    demux_sys_t *p_sys = p_demux->p_sys;
+    int64_t i_current_pos = -1, i_size = 0, i_end = 0;
+    int i;
+
+    if( !var_CreateGetInteger( p_demux, "ps-trust-timestamps" ) )
+        return;
+
+    if( p_sys->i_length == -1 ) /* First time */
+    {
+        p_sys->i_length = 0;
+        /* Check beginning */
+        i = 0;
+        i_current_pos = stream_Tell( p_demux->s );
+        while( vlc_object_alive (p_demux) && i < 40 && Demux2( p_demux, false ) > 0 ) i++;
+
+        /* Check end */
+        i_size = stream_Size( p_demux->s );
+        i_end = __MAX( 0, __MIN( 200000, i_size ) );
+        stream_Seek( p_demux->s, i_size - i_end );
+        i = 0;
+
+        while( vlc_object_alive (p_demux) && i < 40 && Demux2( p_demux, true ) > 0 );
+        if( i_current_pos >= 0 ) stream_Seek( p_demux->s, i_current_pos );
+    }
+
+    for( i = 0; i < PS_TK_COUNT; i++ )
+    {
+        ps_track_t *tk = &p_sys->tk[i];
+        if( tk->i_first_pts >= 0 && tk->i_last_pts > 0 )
+            if( tk->i_last_pts > tk->i_first_pts )
+            {
+                int64_t i_length = (int64_t)tk->i_last_pts - tk->i_first_pts;
+                if( i_length > p_sys->i_length )
+                {
+                    p_sys->i_length = i_length;
+                    p_sys->i_time_track = i;
+                    msg_Dbg( p_demux, "we found a length of: %"PRId64, p_sys->i_length );
+                }
+            }
+    }
+}
+
 /*****************************************************************************
  * Demux:
  *****************************************************************************/
@@ -177,10 +289,19 @@ static int Demux( demux_t *p_demux )
     }
     else if( i_ret == 0 )
     {
-        msg_Warn( p_demux, "garbage at input" );
+        if( !p_sys->b_lost_sync )
+            msg_Warn( p_demux, "garbage at input, trying to resync..." );
+
+        p_sys->b_lost_sync = true;
         return 1;
     }
 
+    if( p_sys->b_lost_sync ) msg_Warn( p_demux, "found sync code" );
+    p_sys->b_lost_sync = false;
+
+    if( p_sys->i_length < 0 && p_sys->b_seekable )
+        FindLength( p_demux );
+
     if( ( p_pkt = ps_pkt_read( p_demux->s, i_code ) ) == NULL )
     {
         return 0;
@@ -195,6 +316,7 @@ static int Demux( demux_t *p_demux )
     case 0x1ba:
         if( !ps_pkt_parse_pack( p_pkt, &p_sys->i_scr, &i_mux_rate ) )
         {
+            if( !p_sys->b_have_pack ) p_sys->b_have_pack = true;
             /* done later on to work around bad vcd/svcd streams */
             /* es_out_Control( p_demux->out, ES_OUT_SET_PCR, p_sys->i_scr ); */
             if( i_mux_rate > 0 ) p_sys->i_mux_rate = i_mux_rate;
@@ -230,6 +352,7 @@ static int Demux( demux_t *p_demux )
     default:
         if( (i_id = ps_pkt_id( p_pkt )) >= 0xc0 )
         {
+            bool b_new = false;
             ps_track_t *tk = &p_sys->tk[PS_ID_TO_TK(i_id)];
 
             if( !tk->b_seen )
@@ -237,12 +360,13 @@ static int Demux( demux_t *p_demux )
                 if( !ps_track_fill( tk, &p_sys->psm, i_id ) )
                 {
                     tk->es = es_out_Add( p_demux->out, &tk->fmt );
+                    b_new = true;
                 }
                 else
                 {
                     msg_Dbg( p_demux, "es id=0x%x format unknown", i_id );
                 }
-                tk->b_seen = VLC_TRUE;
+                tk->b_seen = true;
             }
 
             /* The popular VCD/SVCD subtitling WinSubMux does not
@@ -260,8 +384,26 @@ static int Demux( demux_t *p_demux )
             p_sys->i_scr = -1;
 
             if( tk->b_seen && tk->es &&
-                !ps_pkt_parse_pes( p_pkt, tk->i_skip ) )
+                (
+#ifdef ZVBI_COMPILED /* FIXME!! */
+                tk->fmt.i_codec == VLC_FOURCC('t','e','l','x') ||
+#endif
+                !ps_pkt_parse_pes( p_pkt, tk->i_skip ) ) )
             {
+                if( !b_new && !p_sys->b_have_pack &&
+                    (tk->fmt.i_cat == AUDIO_ES) &&
+                    (p_pkt->i_pts > 0) )
+                {
+                    /* A hack to sync the A/V on PES files. */
+                    msg_Dbg( p_demux, "force SCR: %"PRId64, p_pkt->i_pts );
+                    es_out_Control( p_demux->out, ES_OUT_SET_PCR, p_pkt->i_pts );
+                }
+
+                if( (int64_t)p_pkt->i_pts > p_sys->i_current_pts )
+                {
+                    p_sys->i_current_pts = (int64_t)p_pkt->i_pts;
+                }
+
                 es_out_Send( p_demux->out, tk->es, p_pkt );
             }
             else
@@ -306,13 +448,18 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
         case DEMUX_SET_POSITION:
             f = (double) va_arg( args, double );
             i64 = stream_Size( p_demux->s );
-
+            p_sys->i_current_pts = 0;
             es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
 
             return stream_Seek( p_demux->s, (int64_t)(i64 * f) );
 
         case DEMUX_GET_TIME:
             pi64 = (int64_t*)va_arg( args, int64_t * );
+            if( p_sys->i_time_track >= 0 && p_sys->i_current_pts > 0 )
+            {
+                *pi64 = p_sys->i_current_pts - p_sys->tk[p_sys->i_time_track].i_first_pts;
+                return VLC_SUCCESS;
+            }
             if( p_sys->i_mux_rate > 0 )
             {
                 *pi64 = (int64_t)1000000 * ( stream_Tell( p_demux->s ) / 50 ) /
@@ -324,7 +471,12 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
 
         case DEMUX_GET_LENGTH:
             pi64 = (int64_t*)va_arg( args, int64_t * );
-            if( p_sys->i_mux_rate > 0 )
+            if( p_sys->i_length > 0 )
+            {
+                *pi64 = p_sys->i_length;
+                return VLC_SUCCESS;
+            }
+            else if( p_sys->i_mux_rate > 0 )
             {
                 *pi64 = (int64_t)1000000 * ( stream_Size( p_demux->s ) / 50 ) /
                     p_sys->i_mux_rate;
@@ -334,6 +486,19 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
             return VLC_EGENERIC;
 
         case DEMUX_SET_TIME:
+            i64 = (int64_t)va_arg( args, int64_t );
+            if( p_sys->i_time_track >= 0 && p_sys->i_current_pts > 0 )
+            {
+                int64_t i_now = p_sys->i_current_pts - p_sys->tk[p_sys->i_time_track].i_first_pts;
+                int64_t i_pos = stream_Tell( p_demux->s );
+                int64_t i_offset = i_pos / (i_now / 1000000) * ((i64 - i_now) / 1000000);
+                stream_Seek( p_demux->s, i_pos + i_offset);
+
+                es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
+                return VLC_SUCCESS;
+            }
+            return VLC_EGENERIC;
+
         case DEMUX_GET_FPS:
         default:
             return VLC_EGENERIC;
@@ -344,13 +509,13 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
  * Divers:
  *****************************************************************************/
 
-/* PSResynch: resynch on a system starcode
+/* PSResynch: resynch on a system startcode
  *  It doesn't skip more than 512 bytes
  *  -1 -> error, 0 -> not synch, 1 -> ok
  */
 static int ps_pkt_resynch( stream_t *s, uint32_t *pi_code )
 {
-    uint8_t *p_peek;
+    const uint8_t *p_peek;
     int     i_peek;
     int     i_skip;
 
@@ -393,11 +558,17 @@ static int ps_pkt_resynch( stream_t *s, uint32_t *pi_code )
 
 static block_t *ps_pkt_read( stream_t *s, uint32_t i_code )
 {
-    uint8_t *p_peek;
+    const uint8_t *p_peek;
     int      i_peek = stream_Peek( s, &p_peek, 14 );
-    int      i_size = ps_pkt_size( p_peek, i_peek );
+    int      i_size;
+    VLC_UNUSED(i_code);
 
-    if( i_size <= 6 && p_peek[3] > 0xba )
+    /* Smallest valid packet */
+    if( i_peek < 6 ) return NULL;
+
+    i_size = ps_pkt_size( p_peek, i_peek );
+
+    if( i_size < 0 || ( i_size <= 6 && p_peek[3] > 0xba ) )
     {
         /* Special case, search the next start code */
         i_size = 6;
