@@ -2,7 +2,7 @@
  r playlistinfo.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2002-2008 the VideoLAN team
- * $Id: 0861b7fffe8d9ba323055ef3c6d15c9e15a57ba1 $
+ * $Id: f0f84553d7805308cab210ff82333051b4c9ff11 $
  *
  * Authors: Benjamin Pracht <bigben at videolan dot org>
  *          Felix Paul Kühne <fkuehne at videolan dot org>
@@ -425,6 +425,13 @@ error:
         _NS("OK"), nil, nil);
 }
 
+- (IBAction)downloadCoverArt:(id)sender
+{
+    playlist_t * p_playlist = pl_Yield( VLCIntf );
+    if( p_item) playlist_AskForArtEnqueue( p_playlist, p_item );
+    pl_Release( VLCIntf );
+}
+
 - (input_item_t *)item
 {
     if( p_item ) vlc_gc_incref( p_item );
