@@ -1,11 +1,11 @@
 /*****************************************************************************
  * ctrl_list.hpp
  *****************************************************************************
- * Copyright (C) 2003 VideoLAN
- * $Id: ctrl_list.hpp 9596 2004-12-17 23:39:34Z ipkiss $
+ * Copyright (C) 2003 the VideoLAN team
+ * $Id$
  *
  * Authors: Cyril Deguet     <asmax@via.ecp.fr>
- *          Olivier Teulire <ipkiss@via.ecp.fr>
+ *          Olivier Teulière <ipkiss@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 #ifndef CTRL_LIST_HPP
@@ -31,6 +31,7 @@
 
 class OSGraphics;
 class GenericFont;
+class GenericBitmap;
 
 
 /// Class for control list
@@ -38,7 +39,8 @@ class CtrlList: public CtrlGeneric, public Observer<VarList>,
     public Observer<VarPercent>
 {
     public:
-        CtrlList( intf_thread_t *pIntf, VarList &rList, GenericFont &rFont,
+        CtrlList( intf_thread_t *pIntf, VarList &rList,
+                  const GenericFont &rFont, const GenericBitmap *pBitmap,
                   uint32_t fgcolor, uint32_t playcolor, uint32_t bgcolor1,
                   uint32_t bgcolor2, uint32_t selColor,
                   const UString &rHelp, VarBool *pVisible );
@@ -66,12 +68,15 @@ class CtrlList: public CtrlGeneric, public Observer<VarList>,
         /// List associated to the control
         VarList &m_rList;
         /// Font
-        GenericFont &m_rFont;
+        const GenericFont &m_rFont;
+        /// Background bitmap
+        /** If NULL, the 2 background colors defined below will be used */
+        const GenericBitmap *m_pBitmap;
         /// Color of normal text
         uint32_t m_fgColor;
         /// Color of the playing item
         uint32_t m_playColor;
-        /// Background colors
+        /// Background colors, used when no background bitmap is given
         uint32_t m_bgColor1, m_bgColor2;
         /// Background of selected items
         uint32_t m_selColor;
@@ -83,10 +88,10 @@ class CtrlList: public CtrlGeneric, public Observer<VarList>,
         int m_lastPos;
 
         /// Method called when the list variable is modified
-        virtual void onUpdate( Subject<VarList> &rList );
+        virtual void onUpdate( Subject<VarList> &rList, void* );
 
         /// Method called when the position variable of the list is modified
-        virtual void onUpdate( Subject<VarPercent> &rPercent );
+        virtual void onUpdate( Subject<VarPercent> &rPercent, void*  );
 
         /// Called when the position is set
         virtual void onPositionChange();
