@@ -2,7 +2,7 @@
  * var.c: object variables for input thread
  *****************************************************************************
  * Copyright (C) 2004-2007 the VideoLAN team
- * $Id$
+ * $Id: d3d1c0c47eb1b1405198639003cac489cc76f5ee $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -226,6 +226,9 @@ void input_ControlVarInit ( input_thread_t *p_input )
         var_SetBool( p_input, "intf-change", true );
         var_Create( p_input, "rate-change", VLC_VAR_BOOL );
         var_SetBool( p_input, "rate-change", true );
+
+        var_Create( p_input, "intf-change-vout", VLC_VAR_BOOL );
+        var_SetBool( p_input, "intf-change-vout", true );
     }
 
     /* Add all callbacks
