@@ -4,7 +4,7 @@
  * interface, such as command line.
  *****************************************************************************
  * Copyright (C) 1998-2007 the VideoLAN team
- * $Id$
+ * $Id: c4b031e5fa284eca5f4fc53bab48ef4b24f64559 $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *
@@ -50,7 +50,7 @@
  * Local prototypes
  *****************************************************************************/
 static void* RunInterface( vlc_object_t *p_this );
-#ifdef __APPLE__
+#if defined( __APPLE__ ) || defined( WIN32 )
 static void * MonitorLibVLCDeath( vlc_object_t *p_this );
 #endif
 static int AddIntfCallback( vlc_object_t *, char const *,
@@ -96,7 +96,7 @@ intf_thread_t* __intf_Create( vlc_object_t *p_this, const char *psz_module )
     if( !p_intf )
         return NULL;
     p_intf->b_interaction = false;
-#ifdef __APPLE__
+#if defined( __APPLE__ ) || defined( WIN32 )
     p_intf->b_should_run_on_first_thread = false;
 #endif
 
@@ -139,7 +139,7 @@ intf_thread_t* __intf_Create( vlc_object_t *p_this, const char *psz_module )
  */
 int intf_RunThread( intf_thread_t *p_intf )
 {
-#ifdef __APPLE__
+#if defined( __APPLE__ ) || defined( WIN32 )
     /* Hack to get Mac OS X Cocoa runtime running
      * (it needs access to the main thread) */
     if( p_intf->b_should_run_on_first_thread )
@@ -261,7 +261,7 @@ static void* RunInterface( vlc_object_t *p_this )
     return NULL;
 }
 
-#ifdef __APPLE__
+#if defined( __APPLE__ ) || defined( WIN32 )
 /*****************************************************************************
  * MonitorLibVLCDeath: Used when b_should_run_on_first_thread is set.
  *****************************************************************************/
