@@ -1,8 +1,8 @@
 /*****************************************************************************
  * xml.c: XML parser wrapper for XML modules
  *****************************************************************************
- * Copyright (C) 2004 VideoLAN
- * $Id: xml.c 10101 2005-03-02 16:47:31Z robux4 $
+ * Copyright (C) 2004 the VideoLAN team
+ * $Id$
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *
@@ -18,13 +18,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-#include <stdlib.h>
-#include <vlc/vlc.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
+#include <vlc_common.h>
 #include "vlc_xml.h"
+#include "../libvlc.h"
 
 /*****************************************************************************
  * xml_Create:
@@ -36,14 +39,15 @@ xml_t *__xml_Create( vlc_object_t *p_this )
 {
     xml_t *p_xml;
 
-    p_xml = vlc_object_create( p_this, VLC_OBJECT_XML );
+    p_xml = vlc_custom_create( p_this, sizeof( *p_xml ), VLC_OBJECT_GENERIC,
+                               "xml" );
     vlc_object_attach( p_xml, p_this );
 
     p_xml->p_module = module_Need( p_xml, "xml", 0, 0 );
     if( !p_xml->p_module )
     {
         vlc_object_detach( p_xml );
-        vlc_object_destroy( p_xml );
+        vlc_object_release( p_xml );
         msg_Err( p_this, "XML provider not found" );
         return NULL;
     }
@@ -58,5 +62,5 @@ void xml_Delete( xml_t *p_xml )
 {
     module_Unneed( p_xml, p_xml->p_module );
     vlc_object_detach( p_xml );
-    vlc_object_destroy( p_xml );
+    vlc_object_release( p_xml );
 }
