@@ -2,7 +2,7 @@
  * sap.c : SAP announce handler
  *****************************************************************************
  * Copyright (C) 2002-2007 the VideoLAN team
- * $Id$
+ * $Id: 11bcbc41b8bd6cab255cac188610f7470a293237 $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Rémi Denis-Courmont <rem # videolan.org>
@@ -121,12 +121,10 @@ sap_handler_t *announce_SAPHandlerCreate( announce_handler_t *p_announce )
     sap_handler_t *p_sap;
 
     p_sap = vlc_custom_create( VLC_OBJECT(p_announce), sizeof( sap_handler_t ),
-                               VLC_OBJECT_ANNOUNCE, "announce" );
+                               VLC_OBJECT_ANNOUNCE, "sap announcer" );
     if( !p_sap )
         return NULL;
 
-    p_sap->psz_object_name = strdup( "sap announcer" );
-
     p_sap->pf_add = announce_SAPAnnounceAdd;
     p_sap->pf_del = announce_SAPAnnounceDel;
 
